==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-11-29 12:50+0000\nLast-Translator: fgsl <flavio.lisboa@serpro.gov.br>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Calendário Padrão"

, "The default calendar to create new events in."
: "O calendário padrão para criar novos eventos em."

, "Default Task List"
: "Lista de Tarefas Padrão"

, "The default task list to create new tasks in."
: "A lista de tarefa padrão para criar novas tarefas em."

, "Sync Devices"
: "Dispositivos de Sincronização"

, "Device ID"
: "ID do dispositivo"

, "Devicetype"
: "Tipo de dispositivo"

, "Owner"
: "Proprietário"

, "Policy"
: "Política"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Modelo"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Nome amigável"

, "OS"
: "Sistema Operacional"

, "OS Language"
: "Linguagem do Sistema Operacional"

, "Phonenumber"
: "Número de Telefone"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Dispositivo"
 ,"Dispositivos"

]
, "Devices"
: "Dispositivos"

, "Active Sync"
: "Syncronização Ativa"

, "Select a Device"
: "Selecione o Dispositivo"

, "No ActiveSync Device registered"
: "Nenhum dispositivo de sincronização ativa registrado"

, "Set as {0} Filter"
: "Atribuir como {0} Filtro"

, "Resetted Sync Filter"
: "Filtro de Sincronização Reestabelecido"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filtro para o dispositivo \"{1}\" está agora \"{2}\""

, "resetted"
: "Reestabelecido"

, "Set Sync Filter"
: "Atribuir Filtro de Sincronização"

, "ID"
: "ID"

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: "Duração do Ping"

, "Ping Folder"
: "Pasta do Ping"

, "Remote Wipe"
: "Limpeza remota"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Último Ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: "Por favor, confirme"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Pesquisa Rápida"

, "Default Policy"
: "Política Padrão"

, "Default Policy installed during setup"
: "Política Padrão instalada durante a configuração"

, "Default policy for new devices"
: "Política padrão para novos dispositivos"

, "Enter the id of the policy to apply to newly created devices."
: "Informe o id da política para aplicar aos mais recentes dispositivos criados"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Desabilitar log de acesso"

, "Disable ActiveSync Access Log creation."
: "Desabilitar criação de Log de Acesso de Sincronização Ativa"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filtra intervalo de tempo para eventos"

, "For how long in the past the events should be synchronized."
: "Por quanto tempo no passado os eventos devem ser sincronizados."

, "Manage ActiveSync devices"
: "Gerenciamento de dispositivos de Sincronização Ativa"

, "See, edit and delete ActiveSync devices"
: "Ver, editar e apagar dispositivos de Sincronização Ativa"

, "Reset ActiveSync devices"
: "Reinicializar dispositivos de Sincronização Ativa"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Reinicializar remotamente dispositivos para o estado de fábrica, apagando todos os dados"














, "Sync Device"
: ""

, "Device"
: "Dispositivo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Active Sync"
: "Syncronização Ativa"

, "Select a Device"
: "Selecione o Dispositivo"

, "No ActiveSync Device registered"
: "Nenhum dispositivo de sincronização ativa registrado"

, "Set as {0} Filter"
: "Atribuir como {0} Filtro"

, "Resetted Sync Filter"
: "Filtro de Sincronização Reestabelecido"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filtro para o dispositivo \"{1}\" está agora \"{2}\""

, "resetted"
: "Reestabelecido"

, "Set Sync Filter"
: "Atribuir Filtro de Sincronização"

, "Sync Devices"
: "Dispositivos de Sincronização"

, "ID"
: "ID"

, "Device ID"
: "ID do dispositivo"

, "Device Type"
: ""

, "Owner"
: "Proprietário"

, "Policy"
: "Política"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Modelo"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Nome amigável"

, "Operating System"
: ""

, "OS Language"
: "Linguagem do Sistema Operacional"

, "Phone Number"
: ""

, "Ping Lifetime"
: "Duração do Ping"

, "Ping Folder"
: "Pasta do Ping"

, "Remote Wipe"
: "Limpeza remota"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Último Ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: "Por favor, confirme"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Pesquisa Rápida"

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Dispositivo"
 ,"Dispositivos"

]
, "Devices"
: "Dispositivos"

, "Devicetype"
: "Tipo de dispositivo"

, "OS"
: "Sistema Operacional"

, "Phonenumber"
: "Número de Telefone"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Calendário Padrão"

, "The default calendar to create new events in."
: "O calendário padrão para criar novos eventos em."

, "Default Task List"
: "Lista de Tarefas Padrão"

, "The default task list to create new tasks in."
: "A lista de tarefa padrão para criar novas tarefas em."

, "Default policy for new devices"
: "Política padrão para novos dispositivos"

, "Enter the id of the policy to apply to newly created devices."
: "Informe o id da política para aplicar aos mais recentes dispositivos criados"

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Desabilitar log de acesso"

, "Disable ActiveSync Access Log creation."
: "Desabilitar criação de Log de Acesso de Sincronização Ativa"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filtra intervalo de tempo para eventos"

, "For how long in the past the events should be synchronized."
: "Por quanto tempo no passado os eventos devem ser sincronizados."

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "Política Padrão"

, "Default Policy installed during setup"
: "Política Padrão instalada durante a configuração"

, "Manage ActiveSync devices"
: "Gerenciamento de dispositivos de Sincronização Ativa"

, "See, edit and delete ActiveSync devices"
: "Ver, editar e apagar dispositivos de Sincronização Ativa"

, "Reset ActiveSync devices"
: "Reinicializar dispositivos de Sincronização Ativa"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Reinicializar remotamente dispositivos para o estado de fábrica, apagando todos os dados"














, "Sync Device"
: ""

, "Device"
: "Dispositivo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
